import pandas as pd
import pytest

from toarstats.trends.interface import calculate_trend


def test_calculate_trend_wrong_method(mean_data):
    with pytest.raises(
            ValueError, match="abc is not recognized, must be 'OLS' or 'quant'"
    ):
        trend = calculate_trend("abc", mean_data)


def test_calculate_trend_wrong_quantile(mean_data):
    with pytest.raises(
            ValueError, match="The quantiles must be strictly between 0 and 1."
    ):
        trend = calculate_trend("quant", mean_data, 1.2)


@pytest.mark.filterwarnings("ignore:Maximum number of iterations")
@pytest.mark.slow
def test_calculate_trend_one_quantile(mean_data):
    trend = calculate_trend("quant", mean_data, 0.5)
    assert list(trend.keys()) == [0.5]


@pytest.mark.filterwarnings("ignore:Maximum number of iterations")
@pytest.mark.slow
def test_calculate_trend_multiple_quantiles(mean_data):
    trends = calculate_trend("quant", mean_data, [0.25, 0.5, 0.75])
    assert list(trends.keys()) == [0.25, 0.5, 0.75]


@pytest.mark.slow
def test_calculate_trend_ols(mean_data):
    trend = calculate_trend("OLS", mean_data)
    assert list(trend.keys()) == ["trend", "uncertainty", "p_value"]
